<template>
    <div>
        <Head title="Profile"/>
        <v-card dense rounded>
            <v-card dense rounded>
                <v-card-title class="text-subtitle-1 font-weight-bold">
                    <v-icon left color="primary">mdi-account-outline</v-icon>
                    Profile
                    <v-spacer/>
                </v-card-title>
            </v-card>
        </v-card>
        <v-divider class="my-2"/>
        <v-card elevation="3">
            <v-card-text>
                <v-row justify="center" align="center">
                    <v-col cols="12" align="center" v-if="!$page.props.auth.user.email_verified_at">
                        <v-alert border="left" text dense color="teal" icon="mdi-information-outline">
                            Email has not been verified. Please, click to verify your email address.
                            <v-spacer/>
                            <v-btn text color="primary" small>
                                <v-icon left small>mdi-open-in-new</v-icon>
                                Verify now
                            </v-btn>
                        </v-alert>
                    </v-col>
                    <v-col align="center">
                        <v-hover>
                            <template v-slot:default="{ hover }">
                                <v-avatar size="144px">
                                    <v-img :src="form.photo"/>
                                    <v-fade-transition>
                                        <v-overlay v-if="hover" absolute color="#036358">
                                            <v-btn v-show="photoChanged" icon @click.stop="removePhoto">
                                                <v-icon>mdi-delete</v-icon>
                                            </v-btn>
                                            <v-btn icon @click.stop="$refs.photoInput.click()">
                                                <v-icon>mdi-pencil</v-icon>
                                            </v-btn>
                                        </v-overlay>
                                    </v-fade-transition>
                                </v-avatar>
                            </template>
                        </v-hover>
                        <input accept="image/*" @change="selectPhoto" type="file" ref="photoInput" v-show="false"/>
                    </v-col>
                </v-row>
                <v-row justify="center" align="center">
                    <v-col cols="8">
                        <v-form class="mt-3">
                            <v-text-field ref="profileName" dense label="Name" v-model="form.name" :loading="loading"
                                          :error-messages="error.name" outlined :readonly="!editName"
                                          :append-icon="editName ? 'mdi-pencil-outline' : 'mdi-pencil-off-outline'"
                                          @click:append="editName = !editName"></v-text-field>
                            <v-text-field ref="profileEmail" dense label="Email" v-model="form.email" :loading="loading"
                                          :error-messages="error.email" outlined :readonly="!editEmail"
                                          :append-icon="editEmail ? 'mdi-pencil-outline' : 'mdi-pencil-off-outline'"
                                          @click:append="editEmail = !editEmail">
                            </v-text-field>

                        </v-form>
                    </v-col>
                    <v-col cols="12" align="center">
                        <v-btn :disabled="!fieldChanged" class="mb-5" :loading="loading" @click="saveUser"
                               color="primary">
                            Update
                            <v-icon right>mdi-content-save-outline</v-icon>
                        </v-btn>
                    </v-col>
                </v-row>
            </v-card-text>
        </v-card>
    </div>
</template>

<script>
import Settings from "../../../Components/Layouts/Settings.vue";
import Setting from "../Setting.vue";

export default {
    name: "Profile",
    layout: [Settings, Setting],
    data() {
        return {
            loading: false,
            error: {
                name: [],
                email: [],
                password: [],
                photo: {}
            },
            rules: [
                value => !!value || 'Please fill this field.'
            ],
            editEmail: false,
            editName: false,
            form: {
                name: this.$page.props.auth.user.name,
                email: this.$page.props.auth.user.email,
                photo: this.$page.props.auth.user.photo
            },
            eventSubscription: null

        }
    },
    watch: {
        editEmail(value) {
            if (value) {
                this.$refs.profileEmail.focus()
            }
        },
        editName(value) {
            if (value) {
                this.$refs.profileName.focus()
            }
        }
    },
    computed: {
        fieldChanged() {
            return this.form.name.trim() !== this.$page.props.auth.user.name
                || this.form.email.trim() !== this.$page.props.auth.user.email
                || this.photoChanged
        },
        photoChanged() {
            return this.form.photo.trim() !== this.$page.props.auth.user.photo
        }
    },
    methods: {
        clearError() {
            for (let i in this.error) {
                this.error[i] = []
            }
        },
        saveUser() {
            this.$inertia.put(this.$route('user.update_profile', this.$page.props.auth.user.id), this.form, {
                onBefore: () => {
                    this.loading = true
                },
                onSuccess: (page) => {
                    this.showSnack(["Successfully saved changes!"])
                },
                onError: (errors) => {
                    if (errors && Object.values(errors).length) {
                        this.showSnack([Object.values(errors)[0], "error"])
                    }
                },
                onFinish: visit => {
                    this.loading = false
                }, preserveState: false,
            });
        },
        selectPhoto(evt) {
            if (evt.target.files.length) {
                let reader = new FileReader();
                reader.onload = () => {
                    this.form.photo = reader.result
                }
                reader.readAsDataURL(evt.target.files[0]);
            }
        },
        removePhoto() {
            this.form.photo = this.$page.props.auth.user.photo
        }
    },
    mounted() {
    }
}
</script>

<style>

</style>
